@@ -10,7 +10,7 @@
 #'
 #' @inheritParams gtexr_arguments
 #'
-#' @return A tibble.
+#' @returns A tibble. Or a list if `.return_raw = TRUE`.
 #' @export
 #' @family Reference Genome Endpoints
 #'
@@ -22,6 +22,8 @@ get_gene_search <- function(geneId,
                             gencodeVersion = "v26",
                             genomeBuild = "GRCh38/hg38",
                             page = 0,
-                            itemsPerPage = 250) {
+                            itemsPerPage = getOption("gtexr.itemsPerPage"),
+                            .verbose = getOption("gtexr.verbose"),
+                            .return_raw = FALSE) {
   gtex_query(endpoint = "reference/geneSearch")
 }
