@@ -8,7 +8,7 @@
 #'
 #' @inheritParams gtexr_arguments
 #'
-#' @return A tibble.
+#' @returns A tibble. Or a list if `.return_raw = TRUE`.
 #' @export
 #' @family Reference Genome Endpoints
 #'
@@ -20,6 +20,8 @@ get_gwas_catalog_by_location <- function(start,
                                          end,
                                          chromosome,
                                          page = 0,
-                                         itemsPerPage = 250) {
+                                         itemsPerPage = getOption("gtexr.itemsPerPage"),
+                                         .verbose = getOption("gtexr.verbose"),
+                                         .return_raw = FALSE) {
   gtex_query(endpoint = "reference/gwasCatalogByLocation")
 }
