@@ -10,7 +10,7 @@
 #'
 #' @inheritParams gtexr_arguments
 #'
-#' @return A tibble.
+#' @returns A tibble. Or a list if `.return_raw = TRUE`.
 #' @export
 #' @family Admin Endpoints
 #'
@@ -19,6 +19,8 @@
 #' get_maintenance_message()
 #' }
 get_maintenance_message <- function(page = 0,
-                                    itemsPerPage = 250) {
+                                    itemsPerPage = getOption("gtexr.itemsPerPage"),
+                                    .verbose = getOption("gtexr.verbose"),
+                                    .return_raw = FALSE) {
   gtex_query(endpoint = "admin/maintenanceMessage")
 }
