@@ -13,7 +13,7 @@
 #'
 #' @inheritParams gtexr_arguments
 #'
-#' @return A tibble.
+#' @returns A tibble. Or a list if `.return_raw = TRUE`.
 #' @export
 #' @family Expression Data Endpoints
 #'
@@ -25,6 +25,8 @@ get_median_transcript_expression <- function(gencodeIds,
                                              datasetId = "gtex_v8",
                                              tissueSiteDetailIds = NULL,
                                              page = 0,
-                                             itemsPerPage = 250){
+                                             itemsPerPage = getOption("gtexr.itemsPerPage"),
+                                             .verbose = getOption("gtexr.verbose"),
+                                             .return_raw = FALSE) {
   gtex_query(endpoint = "expression/medianTranscriptExpression")
 }
