@@ -8,7 +8,7 @@
 #'
 #' @inheritParams gtexr_arguments
 #'
-#' @return A tibble.
+#' @returns A tibble. Or a list if `.return_raw = TRUE`.
 #' @export
 #' @family Reference Genome Endpoints
 #'
@@ -20,6 +20,10 @@ get_neighbor_gene <- function(pos,
                               chromosome,
                               bp_window,
                               page = 0,
-                              itemsPerPage = 250) {
+                              gencodeVersion = "v26",
+                              genomeBuild = "GRCh38/hg38",
+                              itemsPerPage = getOption("gtexr.itemsPerPage"),
+                              .verbose = getOption("gtexr.verbose"),
+                              .return_raw = FALSE) {
   gtex_query(endpoint = "reference/neighborGene")
 }
