@@ -12,7 +12,7 @@
 #'
 #' @inheritParams gtexr_arguments
 #'
-#' @return A tibble.
+#' @returns A tibble. Or a list if `.return_raw = TRUE`.
 #' @export
 #' @family Static Association Endpoints
 #'
@@ -20,9 +20,11 @@
 #' \dontrun{
 #' get_sqtl_genes("Whole_Blood")
 #' }
-get_sqtl_genes <- function(tissueSiteDetailId,
+get_sqtl_genes <- function(tissueSiteDetailIds = NULL,
                            datasetId = "gtex_v8",
                            page = 0,
-                           itemsPerPage = 250){
+                           itemsPerPage = getOption("gtexr.itemsPerPage"),
+                           .verbose = getOption("gtexr.verbose"),
+                           .return_raw = FALSE) {
   gtex_query(endpoint = "association/sgene")
 }
