@@ -6,23 +6,25 @@
 #' release.
 #'
 #' [GTEx Portal API
-#' documentation](https://gtexportal.org/api/v2/redoc#tag/Datasets-Endpoints/operation/get_tissue_site_detail_api_v2_dataset_tissueSiteDetail_get)
+#' documentation](https://gtexportal.org/api/v2/redoc#tag/Datasets-Endpoints/operation/get_subject_api_v2_dataset_subject_get)
 #'
 #' @inheritParams gtexr_arguments
-#' @return A Tibble
+#' @returns A tibble. Or a list if `.return_raw = TRUE`.
 #' @export
 #' @family Datasets Endpoints
 #'
 #' @examples
 #' \dontrun{
-#'   get_subject()
+#' get_subject()
 #' }
 get_subject <- function(datasetId = "gtex_v8",
                         sex = NULL,
                         ageBrackets = NULL,
-                        hardyScales = NULL,
+                        hardyScale = NULL,
                         subjectIds = NULL,
                         page = 0,
-                        itemsPerPage = 250){
+                        itemsPerPage = getOption("gtexr.itemsPerPage"),
+                        .verbose = getOption("gtexr.verbose"),
+                        .return_raw = FALSE) {
   gtex_query(endpoint = "dataset/subject")
 }
