@@ -11,7 +11,7 @@
 #'
 #' @inheritParams gtexr_arguments
 #'
-#' @return A tibble.
+#' @returns A tibble. Or a list if `.return_raw = TRUE`.
 #' @export
 #' @family Reference Genome Endpoints
 #'
@@ -23,6 +23,8 @@ get_transcripts <- function(gencodeId,
                             gencodeVersion = "v26",
                             genomeBuild = "GRCh38/hg38",
                             page = 0,
-                            itemsPerPage = 250) {
+                            itemsPerPage = getOption("gtexr.itemsPerPage"),
+                            .verbose = getOption("gtexr.verbose"),
+                            .return_raw = FALSE) {
   gtex_query(endpoint = "reference/transcript")
 }
