@@ -1,9 +1,11 @@
 test_that("`get_image()` returns tibble with expected colnames", {
   skip_if_offline()
   # no `pathologyNotesCategories` column
-  result <- get_image(tissueSampleIds = "GTEX-1117F-0226",
-                      page = 0,
-                      itemsPerPage = 1) |>
+  result <- get_image(
+    tissueSampleIds = "GTEX-1117F-0226",
+    page = 0,
+    itemsPerPage = 1
+  ) |>
     suppressWarnings()
 
   expect_s3_class(result, "tbl_df")
@@ -25,9 +27,11 @@ test_that("`get_image()` returns tibble with expected colnames", {
   )
 
   # `pathologyNotesCategories` column present
-  result <- get_image(tissueSampleIds = "GTEX-1117F-0526",
-                      page = 0,
-                      itemsPerPage = 1) |>
+  result <- get_image(
+    tissueSampleIds = "GTEX-1117F-0526",
+    page = 0,
+    itemsPerPage = 1
+  ) |>
     suppressWarnings()
 
   expect_s3_class(result, "tbl_df")
@@ -49,6 +53,8 @@ test_that("`get_image()` returns tibble with expected colnames", {
     )
   )
 
-  expect_identical(names(result$pathologyNotesCategories),
-                   c("monckeberg", "sclerotic"))
+  expect_identical(
+    names(result$pathologyNotesCategories),
+    c("monckeberg", "sclerotic")
+  )
 })
